#!/usr/bin/env python
# coding: utf-8

# # Run Experiment For Set Duration
# 
# This examples shows how to use Python to control the Synapse mode and
# monitor recording status. <br />
# This uses the 'ExperimentSetTime' example experiment, but it could run with any
# experiment.
# 
# ## Housekeeping
# 
# Import tdt library for SynapseAPI, and Python's built-in time library so we can add a pause
# 

# In[1]:


import time
import tdt


# ## Setup
# 
# Choose which experiment to run and the duration. It could be anything. <br />
# This example uses a simple experiment with just a Tick store. <br />
# To see full list of available experiments use syn.getKnownExperiments()

# In[2]:


EXPERIMENT = 'ExperimentSetTime'
TOTAL_TIME = 30

# Connect to Synapse
syn = tdt.SynapseAPI()

# Set your experiment
syn.setCurrentExperiment(EXPERIMENT)


# ## Runtime

# In[3]:



# Set the system to 'Preview' mode
syn.setModeStr('Preview')

# Wait five seconds to give 'getSystemStatus' time to update internally
time.sleep(5)


# ## Main Loop

# In[4]:


currTime = 0
prevTime = 0

# Poll the system status until it reaches the desired state
while currTime < TOTAL_TIME:

    # Add any additional API controls here
    currTime = syn.getSystemStatus()['recordSecs']
    if prevTime != currTime:
        print(f'Current elapsed time: {currTime}s')

    prevTime = currTime


# Our desired elapsed time has passed, switch to Idle mode

# In[5]:


syn.setModeStr('Idle')
print('done')

